@@ -1,13 +1,14 @@
 from cadet import Cadet
 from joblib import Parallel, delayed
-from .test_dll import setup_model
+import pytest
+from tests.test_dll import setup_model
 
 n_jobs = 2
 
 
 def run_simulation(model):
     model.save()
-    data = model.run_load()
+    data = model.run_simulation()
     model.delete_file()
 
     return data
